@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1769 2025/12/12 18:19:46 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.1771 2025/12/15 16:33:59 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -497,6 +497,8 @@ my $stem_extensions = {
 	'ipython3' => 'ipython',
 	'js128' => 'js140',
 	'g95' => 'gfortran',
+	'py-dns' => 'py3-dns',
+	'py-game' => 'py3-game',
 };
 
 my $obsolete_reason = {};
